1 Jun 2020
    - Improved texttaglib (lite) module
      - Better TTL-JSON support
      - Standardized TTL access methods (find(), find_all() to get_tag(), get_tags())
    - Improved chirptext.sino module (Kangxi radical information)
    - Rename TextReport.file to TextReport.stream (more intuitive)
    - Show fewer mecab related warnings
    - Use Markdown for PyPI project README file

9 Sep 2015
	- Reorganise project structure
